pub struct PartyMemberPreview {
pub id: Uuid,
pub username: String,
pub photo_url: String,
pub power: i64,
pub adjusted_power: Option<i64>,
pub class_id: ClassId,
pub active_abilities: EquippedAbilities,
}Fields
id: Uuidusername: Stringphoto_url: Stringpower: i64adjusted_power: Option<i64>class_id: ClassIdactive_abilities: EquippedAbilitiesTrait Implementations
Sourceimpl Clone for PartyMemberPreview
impl Clone for PartyMemberPreview
Sourcefn clone(&self) -> PartyMemberPreview
fn clone(&self) -> PartyMemberPreview
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for PartyMemberPreview
impl CustomType for PartyMemberPreview
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for PartyMemberPreview
impl Debug for PartyMemberPreview
Sourceimpl Default for PartyMemberPreview
impl Default for PartyMemberPreview
Sourcefn default() -> PartyMemberPreview
fn default() -> PartyMemberPreview
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PartyMemberPreview
impl<'de> Deserialize<'de> for PartyMemberPreview
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<PartyMemberPreview> for JsValuewhere
PartyMemberPreview: Serialize,
impl From<PartyMemberPreview> for JsValuewhere
PartyMemberPreview: Serialize,
Sourcefn from(value: PartyMemberPreview) -> Self
fn from(value: PartyMemberPreview) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for PartyMemberPreviewwhere
Self: DeserializeOwned,
impl FromWasmAbi for PartyMemberPreviewwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for PartyMemberPreviewwhere
PartyMemberPreview: Serialize,
impl IntoWasmAbi for PartyMemberPreviewwhere
PartyMemberPreview: Serialize,
Sourceimpl JsonSchema for PartyMemberPreview
impl JsonSchema for PartyMemberPreview
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for PartyMemberPreviewwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for PartyMemberPreviewwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for PartyMemberPreviewwhere
PartyMemberPreview: Serialize,
impl OptionIntoWasmAbi for PartyMemberPreviewwhere
PartyMemberPreview: Serialize,
Sourceimpl PartialEq for PartyMemberPreview
impl PartialEq for PartyMemberPreview
Sourceimpl RefFromWasmAbi for PartyMemberPreviewwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for PartyMemberPreviewwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<PartyMemberPreview>
type Anchor = SelfOwner<PartyMemberPreview>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for PartyMemberPreview
impl Serialize for PartyMemberPreview
Sourceimpl Tsify for PartyMemberPreview
impl Tsify for PartyMemberPreview
const DECL: &'static str = "export interface PartyMemberPreview {\n id: Uuid;\n username: string;\n photo_url: string;\n power: number;\n adjusted_power: number | null;\n class_id: ClassId;\n active_abilities: EquippedAbilities;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for PartyMemberPreviewwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for PartyMemberPreviewwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for PartyMemberPreviewwhere
PartyMemberPreview: Serialize,
impl VectorIntoWasmAbi for PartyMemberPreviewwhere
PartyMemberPreview: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for PartyMemberPreview
impl WasmDescribeVector for PartyMemberPreview
impl Eq for PartyMemberPreview
impl StructuralPartialEq for PartyMemberPreview